/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "seg7.h"
#include "Display.h"
#include "my define.h"
#include "adc_deal.h"
/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char DisplayBuffer[20]={0};

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
extern void Delay(unsigned int num);

void DisplayInit(void)
{
  clk_10=0xFF16;  //LCD CLK=LS_CK
  DrvLCD_VLCDMode(E_VLCD30);
  DrvLCD_LcdDuty (E_LCD_DUTY4);
  DrvLCD_LCDBuffer(ENABLE);

  DrvLCD_IOMode(5,0xFF);  /*Set SEG1/0 to LCD mode*/
  DrvLCD_IOMode(0,0xFF);  /*Set PT6 to LCD mode*/
  DrvLCD_IOMode(1,0xFF);  /*Set PT7 to LCD mode*/
  DrvLCD_IOMode(2,0xFF);  /*Set PT8 to LCD mode*/
  DrvLCD_IOMode(3,0xFF);  /*Set PT9 to LCD mode*/
  DrvLCD_IOMode(4,0x00);  /*Set PT10 to IO mode*/
}

/*--------------------------------------------------------------------------*/
/* Clear LCD RAM Data                                                       */
/*--------------------------------------------------------------------------*/
void ClearLCDframe(void)
{
  int i=0;
  for(i=0;i<11;i++)
  {
    DisplayBuffer[i]=0x00;
  }
  RAM2LCD(DisplayBuffer,11);
}

/*----------------------------------------------------------------------------*/
/* Display HYcon Char                                                         */
/*----------------------------------------------------------------------------*/
void DisplayHYcon(void)
{
  DisplayBuffer[0]=0x00;
  DisplayBuffer[1]=Char_H;
  DisplayBuffer[2]=Char_Y;
  DisplayBuffer[3]=Char_c;
  DisplayBuffer[4]=Char_o;
  DisplayBuffer[5]=Char_n;
  DisplayBuffer[6]=0x00;
  DisplayBuffer[7]=0x00;
  DisplayBuffer[8]=0x00;
  RAM2LCD(DisplayBuffer,11);
}

/*---------------------------------------------------------------------------*/
/* LCD DISPLAY PASS                                                          */
/*---------------------------------------------------------------------------*/
void DisplayPASS(unsigned char LcdBuffer)
{
  DisplayBuffer[0]=Char_P;
  DisplayBuffer[1]=Char_A;
  DisplayBuffer[2]=Char_S;
  DisplayBuffer[3]=Char_S;
  DisplayBuffer[4]=seg[LcdBuffer/10];
  DisplayBuffer[5]=seg[LcdBuffer%10];
  DisplayBuffer[6]=0xF0;
  DisplayBuffer[7]=0x00;
  DisplayBuffer[8]=0xF0;
  RAM2LCD(DisplayBuffer,11);
}

/*---------------------------------------------------------------------------*/
/* LCD DISPLAY error                                                          */
/*---------------------------------------------------------------------------*/
void Displayerror(void)
{
	DisplayBuffer[0]=0x00;
	DisplayBuffer[1]=Char_E;
	DisplayBuffer[2]=Char_r;
	DisplayBuffer[3]=Char_r;
	DisplayBuffer[4]=Char_o;
	DisplayBuffer[5]=Char_r;
	DisplayBuffer[6]=0x00;
	DisplayBuffer[7]=0x00;
	DisplayBuffer[8]=0x00;
	RAM2LCD(DisplayBuffer,11);
}

/*---------------------------------------------------------------------------*/
/* LCD DISPLAY cal                                                          */
/*---------------------------------------------------------------------------*/
void Displaycal(void)
{
	DisplayBuffer[0]=0x00;
	DisplayBuffer[1]=0x00;
	DisplayBuffer[2]=0x00;
	DisplayBuffer[3]=Char_C;
	DisplayBuffer[4]=Char_A;
	DisplayBuffer[5]=Char_L;
	DisplayBuffer[6]=0x00;
	DisplayBuffer[7]=0x00;
	DisplayBuffer[8]=0x00;
	RAM2LCD(DisplayBuffer,11);
}


/*----------------------------------------------------------------------------*/
/*  calibrate_ok befor Display 9--0                                                         */
/*----------------------------------------------------------------------------*/
void Displaycal_ok(void)
{
	int i;
	for(i=9;i>0;i--)
	{
		  DisplayBuffer[0]=seg[i];
		  DisplayBuffer[1]=seg[i];
		  DisplayBuffer[2]=seg[i];
		  DisplayBuffer[3]=seg[i];
		  DisplayBuffer[4]=seg[i];
		  DisplayBuffer[5]=seg[i];
		  DisplayBuffer[6]=0x00;
		  DisplayBuffer[7]=0x00;
		  DisplayBuffer[8]=0x00;
		  RAM2LCD(DisplayBuffer,11);
		  Delay(50000);
	}

}

/*----------------------------------------------------------------------------*/
/* Display RAM Data                                                           */
/*----------------------------------------------------------------------------*/
/* *****************************************************************************
 * name    : LCD_DATA_DISPLAY
 * function: display the weight
 * input   :
 * output  :
 * note    :
 * ****************************************************************************/
void LCD_DATA_DISPLAY(unsigned int LcdBuffer)
{
  int i;
  int8_t MINUS;

  if((LcdBuffer<0)||(LcdBuffer>0x80000000))
  {
    LcdBuffer=~LcdBuffer;
    LcdBuffer++;
    MINUS=1;
  }
  else
  {
    MINUS=0;
  }

  for(i=5;i>=0;i--)
  {
    DisplayBuffer[i]=seg[LcdBuffer%10];
    LcdBuffer=LcdBuffer/10;
  }
  DisplayBuffer[5]=DisplayBuffer[5]+seg_wg;  //light on 'g'
  if(decimal_piont!=0)
	  DisplayBuffer[4-decimal_piont]=DisplayBuffer[4-decimal_piont]+seg_h;  //setting decimal piont ;
  if(decimal_piont>1)
	  DisplayBuffer[7]=S9;   //light on 'k'
  else
	  DisplayBuffer[7]=0;
  if(MINUS==1||sys_flag0&0x20)   //show the weight
  {
	  DisplayBuffer[6]=seg_neg;
  }

  else
  {
	  DisplayBuffer[6]=0x00;
  }
  if(sys_flag0&0x10)
  {
	  DisplayBuffer[6]=DisplayBuffer[6]+seg_tare;
  }

  RAM2LCD(DisplayBuffer,11);
}

/***************************************************************************
 * name    : LCD_Cal_Display(unsigned int LCDBUFFER)
 * Function: display the calibration
 * input   : data
 * output  : no
 * date    : 2014-12-28
 * note    : no
 * modify  : no
 **************************************************************************/
void LCD_Cal_Display(void)
{
	int LcdBuffer;
	int i;
	if(cal_flag!=0)
	{
		switch(cal_flag)
		{
		case 0x55:                 //display adc
			{
				LCD_ADC_Display(adcout);
				break;
			}

		case 0x01:                 //setting full range
		{
			  LcdBuffer=full_range;
			  for(i=5;i>=0;i--)
			  {
			    DisplayBuffer[i]=seg[LcdBuffer%10];
			    LcdBuffer=LcdBuffer/10;
			  }
			  DisplayBuffer[5]=DisplayBuffer[5]+seg_wg;  //light on 'g'
			  /*if(decimal_piont!=0)
				  DisplayBuffer[5-decimal_piont]=DisplayBuffer[5-decimal_piont]+seg_h;  //setting decimal point ;
			  if(decimal_piont>1)
				  DisplayBuffer[7]=S9+S_A;   //light on 'k'
			  else//*/
				  DisplayBuffer[7]=0+S_A;

			break;
		}
		case 0x02:                      //setting calibration stander weight
		{
			LcdBuffer=stander_wg;
			  for(i=5;i>=0;i--)
			  {
			    DisplayBuffer[i]=seg[LcdBuffer%10];
			    LcdBuffer=LcdBuffer/10;
			  }
			  DisplayBuffer[5]=DisplayBuffer[5]+seg_wg;  //light on 'g'
              /*if(decimal_piont!=0)
            	  DisplayBuffer[5-decimal_piont]=DisplayBuffer[5-decimal_piont]+seg_h;  //setting decimal point ;
			  if(decimal_piont>1)
				  DisplayBuffer[7]=S9+S_A;   //light on 'k'
			  else//*/
				  DisplayBuffer[7]=0+S_A;
			break;
		}
		case 0x04:                               //setting the 'resolution'
		{

		   LcdBuffer=resolution ;// (int)(resolution*10);
		   for(i=5;i>=0;i--)
			  {
			    DisplayBuffer[i]=seg[LcdBuffer%10];
			    LcdBuffer=LcdBuffer/10;
			  }

			DisplayBuffer[6]=0;
			DisplayBuffer[7]=0+S_A;
			DisplayBuffer[5]=DisplayBuffer[5]+seg_wg;  //light on 'g'
			DisplayBuffer[4]=DisplayBuffer[4]+seg_h;  //setting decimal point ;

			break;
		}
		case 0x08:                                    //setting 'decimal point' position
		{

			  for(i=5;i>=(5-decimal_piont);i--)
			  {
			    DisplayBuffer[i]=seg[0];
			  }
			  for(i=0;i<(5-decimal_piont);i++)
			  {
			    DisplayBuffer[i]=0;
			  }
			  DisplayBuffer[5]=seg[1]+seg_wg;  //light on 'g'
              if(decimal_piont!=0)
            	  DisplayBuffer[5-decimal_piont]=DisplayBuffer[5-decimal_piont]+seg_h;  //setting decimal point ;
			  DisplayBuffer[0]=seg[decimal_piont];     //display decimal
			  if(decimal_piont>1)
					DisplayBuffer[7]=S9+S_A;   //light on 'k'
			  else
				  DisplayBuffer[7]=0+S_A;

			break;
		}
		case 0x10:    //show the ENOB
		{
			DisplayBuffer[0]=seg[0xe];
			DisplayBuffer[1]=Char_n ;
			DisplayBuffer[2]=Char_o;
			DisplayBuffer[3]=seg[0xb];
			DisplayBuffer[4]=seg[adc_enob/10];
			DisplayBuffer[5]=seg[adc_enob%10];

			DisplayBuffer[6]=0;
			DisplayBuffer[7]=0+S_A;

			break;
		}
		case 0x20:
		{
			DisplayBuffer[0]=Char_C;
			DisplayBuffer[1]=Char_A;
			DisplayBuffer[2]=Char_L;
			DisplayBuffer[3]=seg[0];
			DisplayBuffer[4]=seg[0];
			DisplayBuffer[5]=seg[0];
			DisplayBuffer[6]=0x00;
			DisplayBuffer[7]=0x00+S_A;
			DisplayBuffer[8]=0x00;
			//RAM2LCD(DisplayBuffer,11);

			break;
		}
		case 0xa0:
		{
			LCD_ADC_Display(adcout);
		/*	  DisplayBuffer[0]=Char_P;
			  DisplayBuffer[1]=Char_A;
			  DisplayBuffer[2]=Char_S;
			  DisplayBuffer[3]=Char_S;
			  DisplayBuffer[4]=seg[0];
			  DisplayBuffer[5]=seg[0];
			  DisplayBuffer[6]=0x00;
			  DisplayBuffer[7]=0x00+S_A;
			  DisplayBuffer[8]=0x00;   */
			 // RAM2LCD(DisplayBuffer,11);
			  break;
		}
		case 0x40:
		{

			DisplayBuffer[0]=Char_C;
			DisplayBuffer[1]=Char_A;
			DisplayBuffer[2]=seg[stander_wg/1000];
			DisplayBuffer[3]=seg[(stander_wg%1000)/100];
			DisplayBuffer[4]=seg[(stander_wg%100)/10];
			DisplayBuffer[5]=seg[stander_wg%10];
			DisplayBuffer[6]=0x00;
			DisplayBuffer[7]=0x00+S_A;
		    DisplayBuffer[8]=0x00;
		    RAM2LCD(DisplayBuffer,11);

			break;
		}
		case 0xc0:
		{
			LCD_ADC_Display(cal_stander_adc);
		/*	  DisplayBuffer[0]=Char_P;
			  DisplayBuffer[1]=Char_A;
			  DisplayBuffer[2]=Char_S;
			  DisplayBuffer[3]=Char_S;
			  DisplayBuffer[4]=Char_c;
			  DisplayBuffer[5]=Char_n;
			  DisplayBuffer[6]=0x00;
			  DisplayBuffer[7]=0x00+S_A;
			  DisplayBuffer[8]=0x00;  */
			 // RAM2LCD(DisplayBuffer,11);
			  break;
		}
		default:
			break;
		}
		RAM2LCD(DisplayBuffer,11);
	}

}
/***************************************************************************
 * name    : LCD_ADC_Display(int LCDBUFFER)
 * Function: display the ADC code
 * input   : data
 * output  : no
 * date    : 2014-12-28
 * note    : no
 * modify  : no
 **************************************************************************/
void LCD_ADC_Display(int LcdBuffer)
{
	  int i;
	  if(LcdBuffer<0)
	    DisplayBuffer[6]=seg_neg;
	  else
	    DisplayBuffer[6]=0x00;
	  DisplayBuffer[7]=0x00;
	  if((LcdBuffer<0)||(LcdBuffer>0x80000000))
	  {
	    LcdBuffer=~LcdBuffer;
	    LcdBuffer++;
	  }
	  for(i=5;i>=0;i--)
	  {
	    DisplayBuffer[i]=seg[LcdBuffer%10];
	    LcdBuffer=LcdBuffer/10;
	  }

	  RAM2LCD(DisplayBuffer,11);
}
/*----------------------------------------------------------------------------*/
/* LCD test                                                      */
/*----------------------------------------------------------------------------*/
void DisplayTest(void)
{
  char count1=1;
  unsigned char DataTxLen1,DataTxLen2;

  for(DataTxLen1=0;DataTxLen1<4;DataTxLen1++)
  {
    for(DataTxLen2=0;DataTxLen2<11;DataTxLen2++)
    {
      DrvLCD_WriteData (DataTxLen2,count1);
      Delay(50000);
    }
    count1=count1<<1;
  }
}

/*----------------------------------------------------------------------------*/
/* RAM Data Send to LCD                                                       */
/*----------------------------------------------------------------------------*/
void RAM2LCD(unsigned char *Buffer_Adr, unsigned char length)
{
  unsigned char DataTxLen;

  for(DataTxLen=0;DataTxLen<length;DataTxLen++)
  {
    DrvLCD_WriteData (DataTxLen,*Buffer_Adr);
    Buffer_Adr++;
  }
}
